@@ -77,6 +77,7 @@ void connman_network_set_group(struct connman_network *network,
 						const char *group);
 const char *connman_network_get_group(struct connman_network *network);
 
+connman_bool_t connman_network_get_connecting(struct connman_network *network);
 int connman_network_set_available(struct connman_network *network,
 						connman_bool_t available);
 connman_bool_t connman_network_get_available(struct connman_network *network);
@@ -95,9 +96,14 @@ void connman_network_set_ipv4_method(struct connman_network *network,
 					enum connman_ipconfig_method method);
 void connman_network_set_ipv6_method(struct connman_network *network,
 					enum connman_ipconfig_method method);
-
-int connman_network_set_address(struct connman_network *network,
-				const void *address, unsigned int size);
+int connman_network_set_ipaddress(struct connman_network *network,
+				struct connman_ipaddress *ipaddress);
+int connman_network_set_nameservers(struct connman_network *network,
+				const char *nameservers);
+int connman_network_set_domain(struct connman_network *network,
+			             const char *domain);
+int connman_network_set_pac(struct connman_network *network,
+				const char *pac);
 int connman_network_set_name(struct connman_network *network,
 							const char *name);
 int connman_network_set_strength(struct connman_network *network,
