@@ -76,13 +76,11 @@ static enum connman_service_type convert_type(uint8_t type)
 
 static GIOStatus rfkill_process(GIOChannel *chan)
 {
-	GIOStatus status = G_IO_STATUS_NORMAL;
 	unsigned char buf[32];
 	struct rfkill_event *event = (void *) buf;
-	char sysname[32];
 	enum connman_service_type type;
-	connman_bool_t blocked;
 	gsize len;
+	GIOStatus status;
 
 	DBG("");
 
@@ -118,19 +116,6 @@ static GIOStatus rfkill_process(GIOChannel *chan)
 		break;
 	}
 
-	snprintf(sysname, sizeof(sysname) - 1, "rfkill%d", event->idx);
-
-	blocked = (event->soft || event->hard) ? TRUE : FALSE;
-
-	switch (event->type) {
-	case RFKILL_TYPE_ALL:
-	case RFKILL_TYPE_WLAN:
-		__connman_udev_rfkill(sysname, blocked);
-		break;
-	default:
-		break;
-	}
-
 	return status;
 }
 
@@ -164,6 +149,9 @@ int __connman_rfkill_init(void)
 	channel = g_io_channel_unix_new(fd);
 	g_io_channel_set_close_on_unref(channel, TRUE);
 
+	g_io_channel_set_encoding(channel, NULL, NULL);
+	g_io_channel_set_buffered(channel, FALSE);
+
 	flags = g_io_channel_get_flags(channel);
 	flags |= G_IO_FLAG_NONBLOCK;
 	g_io_channel_set_flags(channel, flags, NULL);
